"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_record_1 = require("../records/ad.record");
const db_1 = require("../utils/db");
const defaultObject = {
    id: 'null',
    name: '[TDD test] Test Name',
    description: 'blacharze ram pam pam',
    price: 9,
    url: 'https://wp.pl',
    lat: 9,
    lon: 9,
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('AdRecord returns data from database for one entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('abc');
    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('Testowa');
}));
test('AdRecord returns null from database for unexisting entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('---');
    expect(ad).toBeNull();
}));
test('AdRecord.findAll returns array of found entries.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
}));
test('AdRecord.findAll returns array of found entries when searching for "a".', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('a');
    expect(ads[0].id).toBeDefined();
}));
test('AdRecord.findAll returns empty array when searching for something that does not exist.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('-----------------------------------------------------');
    expect(ads).toEqual([]);
}));
test('AdRecord.insert returns UUID.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObject);
    yield ad.insert();
    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
}));
test('AdRecord.insert inserts data to database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObject);
    yield ad.insert();
    const foundAd = yield ad_record_1.AdRecord.getOne(ad.id);
    console.log(foundAd);
    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);
}));
//# sourceMappingURL=ad.test.js.map